==> zio-aws-cloudfront_2.13-5.17.157.1-sources.jar: zio/aws/cloudfront/model/DescribeFunctionRequest.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeFunctionRequest(
    name: String,
    stage: Option[zio.aws.cloudfront.model.FunctionStage] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest = {
    import DescribeFunctionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
      .builder()
      .name(name: java.lang.String)
      .optionallyWith(stage.map(value => value.unwrap))(_.stage)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.DescribeFunctionRequest.ReadOnly =
    zio.aws.cloudfront.model.DescribeFunctionRequest.wrap(buildAwsValue())
}
object DescribeFunctionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.DescribeFunctionRequest =
      zio.aws.cloudfront.model
        .DescribeFunctionRequest(name, stage.map(value => value))
    def name: String
    def stage: Option[zio.aws.cloudfront.model.FunctionStage]
    def getName: ZIO[Any, Nothing, String] = ZIO.succeed(name)
    def getStage: ZIO[Any, AwsError, zio.aws.cloudfront.model.FunctionStage] =
      AwsError.unwrapOptionField("stage", stage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
  ) extends zio.aws.cloudfront.model.DescribeFunctionRequest.ReadOnly {
    override val name: String = impl.name(): String
    override val stage: Option[zio.aws.cloudfront.model.FunctionStage] = scala
      .Option(impl.stage())
      .map(value => zio.aws.cloudfront.model.FunctionStage.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
  ): zio.aws.cloudfront.model.DescribeFunctionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-cloudfront_2.13-5.19.17.1-sources.jar: zio/aws/cloudfront/model/DescribeFunctionRequest.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeFunctionRequest(
    name: String,
    stage: Optional[zio.aws.cloudfront.model.FunctionStage] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest = {
    import DescribeFunctionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
      .builder()
      .name(name: java.lang.String)
      .optionallyWith(stage.map(value => value.unwrap))(_.stage)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.DescribeFunctionRequest.ReadOnly =
    zio.aws.cloudfront.model.DescribeFunctionRequest.wrap(buildAwsValue())
}
object DescribeFunctionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.DescribeFunctionRequest =
      zio.aws.cloudfront.model
        .DescribeFunctionRequest(name, stage.map(value => value))
    def name: String
    def stage: Optional[zio.aws.cloudfront.model.FunctionStage]
    def getName: ZIO[Any, Nothing, String] = ZIO.succeed(name)
    def getStage: ZIO[Any, AwsError, zio.aws.cloudfront.model.FunctionStage] =
      AwsError.unwrapOptionField("stage", stage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
  ) extends zio.aws.cloudfront.model.DescribeFunctionRequest.ReadOnly {
    override val name: String = impl.name(): String
    override val stage: Optional[zio.aws.cloudfront.model.FunctionStage] =
      zio.aws.core.internal
        .optionalFromNullable(impl.stage())
        .map(value => zio.aws.cloudfront.model.FunctionStage.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
  ): zio.aws.cloudfront.model.DescribeFunctionRequest.ReadOnly = new Wrapper(
    impl
  )
}
